import { Collection, DefaultDataItem, ItemKey, State, Agile } from '../internal';
export declare type GroupKey = string | number;
export interface GroupAddOptionsInterface {
    method?: 'unshift' | 'push';
    overwrite?: boolean;
    background?: boolean;
}
export interface GroupConfigInterface {
    key?: GroupKey;
}
export declare class Group<DataType = DefaultDataItem> extends State<Array<ItemKey>> {
    collection: () => Collection<DataType>;
    _output: Array<DataType>;
    _states: Array<() => State<DataType>>;
    notFoundPrimaryKeys: Array<ItemKey>;
    constructor(agileInstance: Agile, collection: Collection<DataType>, initialItems?: Array<ItemKey>, config?: GroupConfigInterface);
    get output(): Array<DataType>;
    get states(): Array<State<DataType>>;
    /**
     * Checks if the group contains the primaryKey
     */
    has(primaryKey: ItemKey): boolean;
    /**
     * Returns the size of the group
     */
    get size(): number;
    /**
     * Removes a item at primaryKey from the group
     */
    remove(itemKeys: ItemKey | ItemKey[], options?: {
        background?: boolean;
    }): this;
    /**
     * Adds a key to a group
     */
    add(itemKeys: ItemKey | ItemKey[], options?: GroupAddOptionsInterface): this;
    /**
     * @internal
     * Will build the group -> it will set the output to the collection values
     */
    build(): void;
}
