"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Integrations = exports.Integration = void 0;
const internal_1 = require("./internal");
class Integration {
    constructor(config) {
        this.config = config;
    }
}
exports.Integration = Integration;
class Integrations {
    constructor(agileInstance) {
        this.loadedIntegrations = new Set();
        this.agileInstance = () => agileInstance;
        // Integrate initial Integrations
        if (internal_1.Agile.initialIntegrations)
            internal_1.Agile.initialIntegrations.forEach(integration => this.integrate(integration));
    }
    //=========================================================================================================
    // Integrate
    //=========================================================================================================
    /**
     * Integrates a framework into Agile
     */
    integrate(integration) {
        if (!(integration instanceof Integration) || !integration.config.name) {
            console.error('Agile: Failed to integrate framework!');
            return;
        }
        this.loadedIntegrations.add(integration);
        if (this.agileInstance().config.logJobs)
            console.log(`Agile: Successfully integrated '${integration.config.name}'`);
    }
    //=========================================================================================================
    // Bind
    //=========================================================================================================
    /**
     * Binds the Framework to Agile
     */
    bind() {
        this.loadedIntegrations.forEach(integration => integration.config.bind && integration.config.bind(this.agileInstance()));
    }
    //=========================================================================================================
    // Update
    //=========================================================================================================
    /**
     * Updates Framework States
     */
    update(componentInstance, updatedData) {
        this.loadedIntegrations.forEach(integration => integration.config.updateMethod && integration.config.updateMethod(componentInstance, updatedData));
    }
    //=========================================================================================================
    // Has Integration
    //=========================================================================================================
    /**
     * Checks weather integrations are registered
     */
    hasIntegration() {
        return this.loadedIntegrations.size > 0;
    }
}
exports.Integrations = Integrations;
