"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Dep = void 0;
class Dep {
    constructor(initialDeps) {
        this.deps = new Set(); // Dependencies from the State
        this.subs = new Set(); // Subscriptions (for instance a component subscribes to a state to get rerendered if the state changes)
        if (!initialDeps)
            return;
        // Add Initial Dependencies to Deps
        initialDeps.forEach(dep => this.deps.add(dep));
    }
    //=========================================================================================================
    // Depend
    //=========================================================================================================
    /**
     * Add new Dependency to the State
     */
    depend(state) {
        if (state.dep !== this && !this.deps.has(state))
            this.deps.add(state);
    }
    //=========================================================================================================
    // Subscribe
    //=========================================================================================================
    /**
     * Add new Subscription to the State
     */
    subscribe(subscriptionContainer) {
        if (!this.subs.has(subscriptionContainer))
            this.subs.add(subscriptionContainer);
    }
    //=========================================================================================================
    // Unsubscribe
    //=========================================================================================================
    /**
     * Delete Subscription from the State
     */
    unsubscribe(subscriptionContainer) {
        if (!this.subs.has(subscriptionContainer))
            this.subs.delete(subscriptionContainer);
    }
}
exports.Dep = Dep;
