"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateValue = exports.persistValue = void 0;
//=========================================================================================================
// Persist Value
//=========================================================================================================
/**
 * Will persist the 'state' into the configured storage with the key or if no key passed the state key
 */
function persistValue(state, key) {
    return __awaiter(this, void 0, void 0, function* () {
        // Validate Key
        const tempKey = validateKey(state, key);
        if (!tempKey) {
            console.error("Agile: If your State has no key provided before using persist.. you have to provide a key here!");
            return;
        }
        key = tempKey;
        // Get Storage
        const storage = state.agileInstance().storage;
        // Check if persist State is already a isPersistState if so remove the old one
        if (state.persistSettings.isPersisted && state.persistSettings.persistKey)
            storage.remove(state.persistSettings.persistKey);
        // Add State to persistedStates in Storage
        storage.persistedStates.add(state);
        // Call Handle which decides weather it has to add the storage value to the state or save the state into the storage
        yield handleStorageValue(key, storage, state);
        // Set persistSettings
        state.persistSettings = {
            isPersisted: true,
            persistKey: key
        };
    });
}
exports.persistValue = persistValue;
//=========================================================================================================
// Update Value
//=========================================================================================================
/**
 * Save current _value into storage if isPersistState
 */
function updateValue(state) {
    if (state.persistSettings.isPersisted && state.persistSettings.persistKey)
        state.agileInstance().storage.set(state.persistSettings.persistKey, state._value);
}
exports.updateValue = updateValue;
//=========================================================================================================
// Helper
//=========================================================================================================
function validateKey(state, key) {
    // Get key from State key
    if (!key && state.key)
        return state.key;
    // Return null if no key can be found
    if (!key)
        return null;
    // Set Storage key as State key if no state key exists
    if (!state.key)
        state.key = key;
    return key;
}
function handleStorageValue(key, storage, state) {
    return __awaiter(this, void 0, void 0, function* () {
        // Get storage Value
        const storageValue = yield storage.get(key);
        // If the value doesn't exist in the storage yet.. create it
        if (!storageValue) {
            storage.set(key, state.getPersistableValue());
            return;
        }
        // If the value already exists in the storage.. load it into the state
        state.set(storageValue);
    });
}
